.. include:: ../README.rst

.. toctree::
    :maxdepth: 0
    :caption: Tutorials
    :glob:

    tutorial_compose_observables
    tutorial_compute_differentiation
    tutorial_dmd_separating_two_mixed_signals_400d_system
    tutorial_dmd_with_control_2d_system
    tutorial_dmd_with_control_128d_system
    tutorial_linear_random_control_system
    tutorial_dmd_succeeds_pde_examples
    tutorial_dmd_failed_for_pde_examples
    tutorial_koopman_edmd_with_rbf
    tutorial_koopman_eigenfunction_model_slow_manifold
    tutorial_koopman_kdmd_on_slow_manifold
    tutorial_koopman_edmdc_for_chaotic_duffing_oscillator
    tutorial_koopman_edmdc_for_vdp_system
    tutorial_koopman_havok_3d_lorenz
    tutorial_koopman_hankel_dmdc_for_vdp_system
    tutorial_koopman_nndmd_examples
    tutorial_linear_system_koopman_eigenfunctions_with_edmd_and_nndmd
    tutorial_sparse_modes_selection_2d_linear_system

.. toctree::
    :maxdepth: 4
    :caption: User Guide

    API Documentation <api/pykoopman>

.. toctree::
    :maxdepth: 1
    :caption: Useful links

    PyKoopman @ PyPI <https://pypi.org/project/pykoopman/>
    Issue Tracker <https://github.com/dynamicslab/pykoopman/issues>
